.. image:: https://readthedocs.org/projects/annotationframeworkclient/badge/?version=latest
    :target: https://annotationframeworkclient.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status
.. image:: https://github.com/seung-lab/AnnotationFrameworkClient/workflows/Annotation%20Framework%20Client/badge.svg
    :target: https://github.com/seung-lab/AnnotationFrameworkClient/actions
    :alt: Actions Status

AnnotationFrameworkClient
###########################
This repository supplies client side code to interact with microservices 
in the Connectome Annotation Versioning Engine (CAVE).
